@@ -1,12 +1,11 @@
 package POE::Component::IRC::Plugin::Bollocks;
+$POE::Component::IRC::Plugin::Bollocks::VERSION = '1.02';
+#ABSTRACT: A POE::Component::IRC plugin that talks bollocks.
 
 use strict;
 use warnings;
 use Dev::Bollocks;
 use POE::Component::IRC::Plugin qw(:ALL);
-use vars qw($VERSION);
-
-$VERSION = '1.00';
 
 my @phrases = (
   "So, let's ", 'We can ', 'We should ', 'Our mission is to ',
@@ -41,19 +40,28 @@ sub S_public {
   return PCI_EAT_NONE unless $command;
   my @cmd = split /\s+/, $command;
   return PCI_EAT_NONE unless uc( $cmd[0] ) eq 'BOLLOCKS';
-  $irc->yield( privmsg => 
-	       $channel => 
+  $irc->yield( privmsg =>
+	       $channel =>
 	       $phrases[int(rand(scalar @phrases))] . Dev::Bollocks->rand( int(rand(3) + 3)) );
   return PCI_EAT_NONE;
 }
 
-1;
+qq[It's all bollocks];
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::IRC::Plugin::Bollocks - A POE::Component::IRC plugin that talks bollocks.
 
+=head1 VERSION
+
+version 1.02
+
 =head1 SYNOPSIS
 
   use strict;
@@ -104,9 +112,11 @@ POE::Component::IRC::Plugin::Bollocks - A POE::Component::IRC plugin that talks
 
 POE::Component::IRC::Plugin::Bollocks is a L<POE::Component::IRC> plugin generates management bullshit whenever you need it.
 
+=for Pod::Coverage PCI_register PCI_unregister S_public
+
 =head1 CONSTRUCTOR
 
-=over 
+=over
 
 =item C<new>
 
@@ -116,7 +126,7 @@ Creates a new plugin object.
 
 =head1 IRC INPUT
 
-=over 
+=over
 
 =item C<BOLLOCKS>
 
@@ -125,18 +135,21 @@ random management bollocks to the channel.
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams.
-
-This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
 L<POE::Component::IRC>
 
 L<Dev::Bollocks>
+
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
